@@ -83,20 +83,16 @@ QString button::getColorString() const
 	switch (m_color)
 	{
 		case blinkenGame::blue:
-			return "blue";
-		break;
+			return QStringLiteral("blue");
 		
 		case blinkenGame::yellow:
-			return "yellow";
-		break;
+			return QStringLiteral("yellow");
 		
 		case blinkenGame::red:
-			return "red";
-		break;
+			return QStringLiteral("red");
 		
 		case blinkenGame::green:
-			return "green";
-		break;
+			return QStringLiteral("green");
 		
 		default:
 			// never happens
